package cd.casic.module.machine.dal.model;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import static cd.casic.framework.commons.exception.util.ServiceExceptionUtil.exception;
import static cd.casic.module.machine.contants.MachineErrorCodeConstants.*;

import java.util.ArrayList;
import java.util.List;

//文件节点类
@Data
/*
 * 远程文件系统的节点信息，用于构建文件树结构
 */
@Schema(description = "远程文件系统节点")
public class FileNode {
    @Schema(description = "文件名或目录名")
    private String name;

    @Schema(description = "是否为目录")
    private boolean isDirectory;

    @Schema(description = "文件大小（字节）")
    private long size;

    @Schema(description = "文件权限字符串（如 rwxr-xr-x）")
    private String permissions;

    @Schema(description = "最后修改时间（时间戳，毫秒）")
    private long modifiedTime;

    @Schema(description = "子节点列表（仅目录有此属性）")
    private List<FileNode> children;

    public FileNode(String name, boolean isDirectory, long size, String permissions, long modifiedTime) {
        this.name = name;
        this.isDirectory = isDirectory;
        this.size = size;
        this.permissions = permissions;
        this.modifiedTime = modifiedTime;

        if (isDirectory) {
            this.children = new ArrayList<>();
        }

    }

    public void addChild(FileNode child) {
        if (this.children == null) {
            throw exception(NOT_DIRECTORY_NODE);
        }
        this.children.add(child);
    }
}
