//package com.casic.machine.service.impl;
//
//import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
//import com.casic.commons.exception.ServiceException;
//import com.casic.commons.utils.PageResult;
//import com.casic.machine.dto.MachineEnvDTO;
//import com.casic.machine.entity.MachineEnv;
//import com.casic.machine.mapper.MachineEnvMapper;
//import com.casic.machine.service.MachineEnvService;
//import org.junit.jupiter.api.BeforeEach;
//import org.junit.jupiter.api.Test;
//import org.springframework.beans.factory.annotation.Autowired;
//import org.springframework.boot.test.context.SpringBootTest;
//import org.springframework.test.annotation.Rollback;
//import org.springframework.test.context.jdbc.Sql;
//import org.springframework.transaction.annotation.Transactional;
//
//import java.util.Date;
//import java.util.List;
//
//import static org.junit.jupiter.api.Assertions.*;
//
//@SpringBootTest
//@Transactional
//@Rollback(value = true) // 测试后回滚数据
//@Sql(scripts = {"classpath:sql/machine_env_test_data.sql"}) // 初始化测试数据（可选）
//public class MachineEnvServiceImplTest {
//
//    @Autowired
//    private MachineEnvService machineEnvService;
//
//    @Autowired
//    private MachineEnvMapper machineEnvMapper;
//
//    private MachineEnvDTO validDto;
//    private MachineEnvDTO invalidKeyDto;
//    private Long existingMachineId;
//    private Long nonExistingMachineId;
//
//    @BeforeEach
//    public void setUp() {
//        // 准备测试数据
//        existingMachineId = 1L; // 假设数据库中存在ID为1的机器环境变量
//        nonExistingMachineId = 999L; // 不存在的机器ID
//
//        // 有效测试数据
//        validDto = new MachineEnvDTO();
//        validDto.setMachineInfoId(existingMachineId);
//        validDto.setEnvKey("TEST_ENV_KEY");
//        validDto.setEnvValue("test-value");
//        validDto.setSensitive(true);
//
//        // 无效Key测试数据（包含非法字符）
//        invalidKeyDto = new MachineEnvDTO();
//        invalidKeyDto.setMachineInfoId(existingMachineId);
//        invalidKeyDto.setEnvKey("test-env-key"); // 包含'-'，不符合正则
//        invalidKeyDto.setEnvValue("test-value");
//    }
//
//    // ==================== 更新环境变量测试 ====================
//    @Test
//    void testUpdateEnv_ValidData_ShouldSucceed() {
//        // 执行更新（假设数据库中已存在machineId=1的记录）
//        boolean result = machineEnvService.update(validDto);
//
//        // 验证结果
//        assertTrue(result);
//
//        // 检查数据库数据是否更新
//        MachineEnv updatedEnv = machineEnvMapper.selectOne(
//                new LambdaQueryWrapper<MachineEnv>().eq(MachineEnv::getMachineId, existingMachineId)
//        );
//        assertNotNull(updatedEnv);
//        assertEquals(validDto.getEnvKey(), updatedEnv.getEnvKey());
//        assertEquals(validDto.getEnvValue(), updatedEnv.getEnvValue());
//        assertEquals(validDto.getSensitive(), updatedEnv.getSensitive());
//    }
//
//    @Test
//    void testUpdateEnv_NullDto_ShouldThrowException() {
//
//        MachineEnvDTO machineEnvDTO = new MachineEnvDTO();
//        assertThrows(ServiceException.class, () -> {
//            machineEnvService.update(machineEnvDTO);
//        }, "环境变量不能为空");
//    }
//
//    @Test
//    void testUpdateEnv_InvalidKey_ShouldThrowException() {
//        assertThrows(ServiceException.class, () -> {
//            machineEnvService.update(invalidKeyDto);
//        }, "环境变量键不合法");
//    }
//
//    @Test
//    void testUpdateEnv_SensitiveKey_ShouldMarkAsSensitive() {
//        MachineEnvDTO sensitiveDto = new MachineEnvDTO();
//        sensitiveDto.setMachineInfoId(existingMachineId);
//        sensitiveDto.setEnvKey("DB_PASSWORD"); // 包含敏感词
//        sensitiveDto.setEnvValue("secret");
//
//        machineEnvService.update(sensitiveDto);
//
//        MachineEnv env = machineEnvMapper.selectOne(
//                new LambdaQueryWrapper<MachineEnv>().eq(MachineEnv::getMachineId, existingMachineId)
//        );
//        assertTrue(env.getSensitive());
//    }
//
//    // ==================== 删除环境变量测试 ====================
//    @Test
//    void testDeleteByMachineId_ExistingId_ShouldSucceed() {
//        machineEnvService.deleteByMachineId(existingMachineId);
//        MachineEnv env = machineEnvMapper.selectById(existingMachineId);
//        assertNull(env);
//    }
//
//    @Test
//    void testDeleteByMachineId_NonExistingId_ShouldDoNothing() {
//        machineEnvService.deleteByMachineId(nonExistingMachineId);
//        // 不抛出异常，静默处理
//    }
//
//    // ==================== 根据机器ID查询测试 ====================
//    @Test
//    void testGetByMachineId_ExistingId_ShouldReturnDto() {
//        MachineEnvDTO dto = machineEnvService.getByMachineId(existingMachineId);
//        assertNotNull(dto);
//        assertEquals(existingMachineId, dto.getMachineInfoId());
//    }
//
//    @Test
//    void testGetByMachineId_NonExistingId_ShouldReturnNull() {
//        MachineEnvDTO dto = machineEnvService.getByMachineId(nonExistingMachineId);
//        assertNull(dto);
//    }
//
//    // ==================== 列表查询测试 ====================
//    @Test
//    void testListEnv_Pagination_ShouldReturnValidPage() {
//        MachineEnvDTO queryDto = new MachineEnvDTO();
//        queryDto.setPageIndex(1);
//        queryDto.setPageSize(10);
//        queryDto.setEnvKey("TEST"); // 假设测试数据中存在包含"TEST"的键
//
//        PageResult<MachineEnvDTO> pageResult = machineEnvService.listEnv(queryDto);
//
//        assertNotNull(pageResult.getList());
//        assertTrue(pageResult.getTotal() >= 0);
//        assertEquals(1, pageResult.getPageNum());
//    }
//
//    @Test
//    void testListEnv_SortByCreateTime_ShouldBeOrdered() {
//        MachineEnvDTO queryDto = new MachineEnvDTO();
//        queryDto.setSortField("createTime");
//        queryDto.setSortDirection("desc");
//
//        PageResult<MachineEnvDTO> pageResult = machineEnvService.listEnv(queryDto);
//
//        List<MachineEnvDTO> list = pageResult.getList();
//        if (!list.isEmpty()) {
//            Date prevDate = list.get(0).getCreateDate();
//            for (int i = 1; i < list.size(); i++) {
//                Date currDate = list.get(i).getCreateDate();
//                assertTrue(currDate.before(prevDate) || currDate.equals(prevDate), "排序应为降序");
//                prevDate = currDate;
//            }
//        }
//    }
//
//    // ==================== 批量删除测试 ====================
//    @Test
//    void testDeleteList_ValidIds_ShouldDeleteBatch() {
//        // 假设测试数据中有ID为1和2的记录
//        List<Long> ids = List.of(1L, 2L);
//        machineEnvService.deleteList(ids);
//
//        long count = machineEnvMapper.selectCount(new LambdaQueryWrapper<MachineEnv>().in(MachineEnv::getId, ids));
//        assertEquals(0, count);
//    }
//
//
//}