//package com.casic.machine.service.impl;
//
//import com.casic.commons.exception.ServiceException;
//import com.casic.machine.dto.MachineInfoDto;
//import com.casic.machine.entity.MachineInfo;
//import com.casic.machine.enums.AuthenticationType;
//import com.casic.machine.enums.ConnectionStatus;
//import com.casic.machine.enums.MachineInfoStatus;
//import org.junit.jupiter.api.BeforeEach;
//import org.junit.jupiter.api.Test;
//import org.springframework.beans.BeanUtils;
//import org.springframework.beans.factory.annotation.Autowired;
//import org.springframework.boot.test.context.SpringBootTest;
//import org.springframework.test.annotation.Rollback;
//import org.springframework.test.context.jdbc.Sql;
//import org.springframework.transaction.annotation.Transactional;
//
//import java.util.Collections;
//
//import static org.junit.jupiter.api.Assertions.*;
//
//@SpringBootTest
//@Transactional
//@Rollback(true)
//@Sql(scripts = {"classpath:sql/machine_info_test_data.sql"})
//public class MachineinfoServiceImplTest {
//
//    @Autowired
//    private MachineinfoServiceImpl machineInfoService;
//
//    private MachineInfoDto validMachineInfoDto;
//    private Long existingMachineId;
//    private Long nonExistingMachineId;
//
//    @BeforeEach
//    public void setUp() {
//        // 初始化测试数据（假设 SQL 脚本已插入一条状态为 ENABLE 的机器）
//        existingMachineId = 1L;
//        nonExistingMachineId = 999L;
//
//        // 有效机器信息 DTO
//        validMachineInfoDto = new MachineInfoDto();
//        validMachineInfoDto.setName("Test Machine");
//        validMachineInfoDto.setHostIp("192.168.1.101");
//        validMachineInfoDto.setSshPort("22");
//        validMachineInfoDto.setUsername("testuser");
//        validMachineInfoDto.setAuthenticationType(AuthenticationType.PASSWORD.getMessage());
//        validMachineInfoDto.setStatus(MachineInfoStatus.ENABLE.getMessage());
//    }
//
//    // ======================= 新增机器测试 =======================
//    @Test
//    void testAddMachineInfo_ValidData_ShouldSucceed() {
//        boolean result = machineInfoService.addMachineInfo(validMachineInfoDto);
//        assertTrue(result);
//
//        // 验证数据库存在记录
//        MachineInfo machineInfo = machineInfoService.getById(validMachineInfoDto.getId());
//        assertNotNull(machineInfo);
//        assertEquals(validMachineInfoDto.getHostIp(), machineInfo.getHostIp());
//        assertEquals(AuthenticationType.PASSWORD.getCode(), machineInfo.getAuthenticationTypeCode());
//    }
//
//    @Test
//    void testAddMachineInfo_NullDto_ShouldThrowException() {
//        assertThrows(ServiceException.class, () -> {
//            machineInfoService.addMachineInfo(null);
//        }, "机器信息为空");
//    }
//
//    // ======================= 列表查询测试 =======================
//    @Test
//    void testListMachineInfo_WithStatusFilter_ShouldReturnValidRecords() {
//        MachineInfoDto queryDto = new MachineInfoDto();
//        queryDto.setStatus(MachineInfoStatus.ENABLE.getMessage());
//
//        var pageResult = machineInfoService.listMachineInfo(queryDto);
//        assertFalse(pageResult.getList().isEmpty());
//        pageResult.getList().forEach(dto ->
//                assertEquals(MachineInfoStatus.ENABLE.getMessage(), dto.getStatus())
//        );
//    }
//
//    @Test
//    void testListMachineInfo_WithHostIpFilter_ShouldFilterRecords() {
//        MachineInfoDto queryDto = new MachineInfoDto();
//        queryDto.setHostIp("192.168.1.100"); // 假设测试数据中的 IP
//
//        var pageResult = machineInfoService.listMachineInfo(queryDto);
//        assertFalse(pageResult.getList().isEmpty());
//        pageResult.getList().forEach(dto ->
//                assertTrue(dto.getHostIp().contains("192.168.1.100"))
//        );
//    }
//
//    // ======================= 更新机器状态测试 =======================
//    @Test
//    void testUpdateStatus_ValidId_ShouldUpdateStatus() {
//        boolean result = machineInfoService.updateStatus(existingMachineId, MachineInfoStatus.UN_ENABLE.getMessage());
//        assertTrue(result);
//
//        MachineInfo machineInfo = machineInfoService.getById(existingMachineId);
//        assertEquals(MachineInfoStatus.UN_ENABLE.getCode(), machineInfo.getStatus());
//    }
//
//    @Test
//    void testUpdateStatus_NonExistingId_ShouldFail() {
//        boolean result = machineInfoService.updateStatus(nonExistingMachineId, MachineInfoStatus.UN_ENABLE.getMessage());
//        assertFalse(result);
//    }
//
//    // ======================= 连接测试 =======================
//    @Test
//    void testTestConnection_EnabledMachine_ShouldSucceed() {
//        MachineInfo machineInfo = machineInfoService.getById(existingMachineId);
//        assertTrue(machineInfoService.testConnection(machineInfo));
//    }
//
//    @Test
//    void testTestConnection_DisabledMachine_ShouldThrowException() {
//        // 先禁用机器
//        machineInfoService.updateStatus(existingMachineId, MachineInfoStatus.UN_ENABLE.getMessage());
//        MachineInfo disabledMachine = machineInfoService.getById(existingMachineId);
//
//        assertThrows(RuntimeException.class, () -> {
//            machineInfoService.testConnection(disabledMachine);
//        }, "机器不可用");
//    }
//
//    // ======================= 会话管理测试 =======================
//    @Test
//    void testConnect_NewMachine_ShouldCreateSession() {
//        MachineInfo machineInfo = machineInfoService.getById(existingMachineId);
//        String sessionId = machineInfoService.connect(machineInfo);
//
//        assertNotNull(sessionId);
//        assertTrue(sessionId.startsWith("session-"));
//        assertEquals(ConnectionStatus.CONNECTING, machineInfoService.getConnectionStatus(machineInfo.getName()));
//    }
//
//
//
//    // ======================= 删除机器测试 =======================
//    @Test
//    void testDeleteMachineInfo_EnabledMachine_ShouldDelete() {
//        machineInfoService.deleteMachineInfo(existingMachineId);
//        assertNull(machineInfoService.getById(existingMachineId));
//    }
//
//    @Test
//    void testDeleteList_ValidIds_ShouldDeleteBatch() {
//        machineInfoService.deleteList(Collections.singletonList(existingMachineId));
//        var list = machineInfoService.list();
//        assertFalse(list.contains(existingMachineId));
//    }
//
//    // ======================= 辅助功能测试 =======================
//    @Test
//    void testAuthenticationTypeConversion() {
//        validMachineInfoDto.setAuthenticationType(AuthenticationType.SECRET_KEY.getMessage());
//        MachineInfo machineInfo = new MachineInfo();
//        BeanUtils.copyProperties(validMachineInfoDto, machineInfo);
//
//        assertEquals(AuthenticationType.SECRET_KEY.getCode(), machineInfo.getAuthenticationTypeCode());
//    }
//
//    @Test
//    void testGetAllConnectionStatus_ShouldReturnStatusMap() {
//        MachineInfo machineInfo = machineInfoService.getById(existingMachineId);
//        machineInfoService.connect(machineInfo);
//
//        var statusMap = machineInfoService.getAllConnectionStatus();
//        assertFalse(statusMap.isEmpty());
//        assertTrue(statusMap.containsValue(ConnectionStatus.CONNECTING));
//    }
//}