package cd.casic.module.process.process.setting.impl;

import cd.casic.ci.commons.bean.process.setting.AuthHostK8s;
import cd.casic.ci.commons.bean.process.setting.AuthHostK8sQuery;
import cd.casic.framework.commons.pojo.PageResult;
import cd.casic.framework.security.core.util.SecurityFrameworkUtils;
import cd.casic.module.process.convert.setting.AuthHostK8sConvert;
import cd.casic.module.process.process.setting.AuthHostK8sService;
import cd.casic.module.process.process.setting.dao.AuthHostK8sDao;
import cd.casic.module.process.process.setting.dataobject.AuthHostK8sDo;
import cn.hutool.core.collection.CollectionUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.List;
import java.util.Objects;

@Service
public class AuthHostK8sServiceImpl implements AuthHostK8sService {

    @Autowired
    AuthHostK8sDao authHostK8sDao;

    /**
     * 创建流水线授权
     *
     * @param authHostK8s 流水线授权
     * @return 流水线授权id
     */
    @Override
    public String createAuthHostK8s(AuthHostK8s authHostK8s) {
        AuthHostK8sDo authHostK8sDo = AuthHostK8sConvert.INSTANCE.convertDo(authHostK8s);
        authHostK8sDo.setUserId(SecurityFrameworkUtils.getLoginUser().getId());
        authHostK8sDao.updateById(authHostK8sDo);
        return authHostK8sDo.getHostId();
    }

    /**
     * 删除流水线授权
     *
     * @param authHostK8sId 流水线授权id
     */
    @Override
    public void deleteAuthHostK8s(String authHostK8sId) {
        authHostK8sDao.deleteById(authHostK8sId);
    }

    /**
     * 更新授权信息
     *
     * @param authHostK8s 信息
     */
    @Override
    public void updateAuthHostK8s(AuthHostK8s authHostK8s) {
        int authPublic = authHostK8s.getAuthPublic();
        String authId = authHostK8s.getHostId();
        AuthHostK8s oneAuth = findOneAuthHostK8s(authId);
        int hostType = oneAuth.getAuthPublic();
        if (authPublic == 1 && hostType == 2) {
            authHostK8s.setPrivateKey("");
        }
        if (authPublic == 2 && hostType == 1) {
            authHostK8s.setUsername("");
            authHostK8s.setPassword("");
        }
        authHostK8sDao.updateById(AuthHostK8sConvert.INSTANCE.convertDo(authHostK8s));
    }

    /**
     * 查询授权信息
     *
     * @param authHostK8sId id
     * @return 信息集合
     */
    @Override
    public AuthHostK8s findOneAuthHostK8s(String authHostK8sId) {
        AuthHostK8sDo authHostK8sDo = authHostK8sDao.selectOne(new QueryWrapper<AuthHostK8sDo>().eq("host_id", authHostK8sId));
        return AuthHostK8sConvert.INSTANCE.convert(authHostK8sDo);
    }

    /**
     * 查询所有流水线授权
     *
     * @return 流水线授权列表
     */
    @Override
    public List<AuthHostK8s> findAllAuthHostK8s() {

        List<AuthHostK8sDo> authHostK8sDos = authHostK8sDao.selectList();
        if (Objects.isNull(authHostK8sDos)) {
            return Collections.emptyList();
        }
        List<AuthHostK8s> authHostK8ss = AuthHostK8sConvert.INSTANCE.convertList(authHostK8sDos);
        return authHostK8ss;
    }

    @Override
    public List<AuthHostK8s> findAllAuthHostK8sList(List<String> idList) {
        List<AuthHostK8sDo> authHostK8sDos = authHostK8sDao.selectList(new QueryWrapper<AuthHostK8sDo>().in("host_id", idList));
        return AuthHostK8sConvert.INSTANCE.convertList(authHostK8sDos);
    }

    @Override
    public List<AuthHostK8s> findAuthHostK8sList(AuthHostK8sQuery hostQuery) {
        PageResult<AuthHostK8sDo> authHostK8sDoPageResult = authHostK8sDao.selectPage(hostQuery.getPageParam(),
                new QueryWrapper<AuthHostK8sDo>().eq("user_id", hostQuery.getUserId()));
        if (Objects.isNull(authHostK8sDoPageResult) || CollectionUtil.isEmpty(authHostK8sDoPageResult.getList())) {
            return Collections.emptyList();
        }
        return AuthHostK8sConvert.INSTANCE.convertList(authHostK8sDoPageResult.getList());
    }

    @Override
    public PageResult<AuthHostK8s> findAuthHostK8sPage(AuthHostK8sQuery hostQuery) {
        PageResult<AuthHostK8sDo> authHostK8sDoPageResult = authHostK8sDao.selectPage(hostQuery.getPageParam(),
                new QueryWrapper<AuthHostK8sDo>().eq("user_id", hostQuery.getUserId()));
        return new PageResult<AuthHostK8s>(
                AuthHostK8sConvert.INSTANCE.convertList(authHostK8sDoPageResult.getList()),
                authHostK8sDoPageResult.getTotal());
    }


    @Override
    public Long findHostNumber() {
        return authHostK8sDao.selectCount();
    }

}
