package cd.casic.module.process.task.build.service;


/**
 * @ClassName TaskArtifactXpackServiceImpl
 * @Author hopeli
 * @Date 2025/5/2 19:30
 * @Version 1.0
 */



import cd.casic.ci.commons.annotation.join.FindAll;
import cd.casic.ci.commons.annotation.join.FindList;
import cd.casic.ci.commons.annotation.join.FindOne;
import cd.casic.ci.commons.annotation.join.JoinProvider;
import cd.casic.module.process.task.build.model.TaskBuild;

import java.util.List;

/**
 * 任务构建服务接口
 */
@JoinProvider(model = TaskBuild.class)
public interface TaskBuildService {

    /**
     * 创建
     * @param TaskBuild build信息
     * @return buildId
     */
    String createBuild(TaskBuild TaskBuild);

    /**
     * 删除
     * @param buildId buildId
     */
    void deleteBuild(String buildId);

    /**
     * 更新
     * @param TaskBuild 更新信息
     */
    void updateBuild(TaskBuild TaskBuild);

    /**
     * 验证
     * @param taskType taskType
     * @param taskBuild object
     * @return Boolean
     */
    Boolean buildValid(String taskType,TaskBuild taskBuild);


    /**
     * 根据配置id查询任务
     * @param configId 配置id
     * @return 任务
     */
    TaskBuild findBuildByAuth(String configId);


    /**
     * 查询单个信息
     * @param buildId buildId
     * @return build信息
     */
    @FindOne
    TaskBuild findOneBuild(String buildId);

    /**
     * 查询所有信息
     * @return build信息集合
     */
    @FindAll
    List<TaskBuild> findAllBuild();

    /**
     * 根据ID列表查询构建
     * @param idList ID列表
     * @return 构建列表
     */
    @FindList
    List<TaskBuild> findAllBuildList(List<String> idList);
}
